# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/functions/v1/function_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.serverless.functions.v1 import function_pb2 as yandex_dot_cloud_dot_serverless_dot_functions_dot_v1_dot_function__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;yandex/cloud/serverless/functions/v1/function_service.proto\x12$yandex.cloud.serverless.functions.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x33yandex/cloud/serverless/functions/v1/function.proto\x1a\x1dyandex/cloud/validation.proto\"/\n\x12GetFunctionRequest\x12\x19\n\x0b\x66unction_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\">\n\x19GetFunctionVersionRequest\x12!\n\x13\x66unction_version_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"h\n\x1eGetFunctionVersionByTagRequest\x12\x19\n\x0b\x66unction_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12+\n\x03tag\x18\x02 \x01(\tB\x1e\xf2\xc7\x31\x1a[a-z][-_0-9a-z]*|[$]latest\"f\n\x14ListFunctionsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"s\n\x15ListFunctionsResponse\x12\x41\n\tfunctions\x18\x01 \x03(\x0b\x32..yandex.cloud.serverless.functions.v1.Function\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xcf\x02\n\x15\x43reateFunctionRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9c\x01\n\x06labels\x18\x04 \x03(\x0b\x32G.yandex.cloud.serverless.functions.v1.CreateFunctionRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16\x43reateFunctionMetadata\x12\x13\n\x0b\x66unction_id\x18\x01 \x01(\t\"\x82\x03\n\x15UpdateFunctionRequest\x12\x19\n\x0b\x66unction_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9c\x01\n\x06labels\x18\x05 \x03(\x0b\x32G.yandex.cloud.serverless.functions.v1.UpdateFunctionRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16UpdateFunctionMetadata\x12\x13\n\x0b\x66unction_id\x18\x01 \x01(\t\"2\n\x15\x44\x65leteFunctionRequest\x12\x19\n\x0b\x66unction_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"-\n\x16\x44\x65leteFunctionMetadata\x12\x13\n\x0b\x66unction_id\x18\x01 \x01(\t\"V\n\x1c\x44\x65leteFunctionVersionRequest\x12!\n\x13\x66unction_version_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\r\n\x05\x66orce\x18\x03 \x01(\x08J\x04\x08\x01\x10\x02\"B\n\x1d\x44\x65leteFunctionVersionMetadata\x12\x1b\n\x13\x66unction_version_id\x18\x02 \x01(\tJ\x04\x08\x01\x10\x02\"\x15\n\x13ListRuntimesRequest\"(\n\x14ListRuntimesResponse\x12\x10\n\x08runtimes\x18\x01 \x03(\t\"\xb0\x01\n\x1cListFunctionsVersionsRequest\x12\x13\n\tfolder_id\x18\x01 \x01(\tH\x00\x12\x15\n\x0b\x66unction_id\x18\x02 \x01(\tH\x00\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000B\n\n\x02id\x12\x04\xc0\xc1\x31\x01\"y\n\x1dListFunctionsVersionsResponse\x12?\n\x08versions\x18\x01 \x03(\x0b\x32-.yandex.cloud.serverless.functions.v1.Version\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x94\x01\n\x1dListFunctionOperationsRequest\x12\x19\n\x0b\x66unction_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"p\n\x1eListFunctionOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xf1\n\n\x1c\x43reateFunctionVersionRequest\x12\x19\n\x0b\x66unction_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x15\n\x07runtime\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05\x30-256\x12\x18\n\nentrypoint\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\x12H\n\tresources\x18\x05 \x01(\x0b\x32/.yandex.cloud.serverless.functions.v1.ResourcesB\x04\xe8\xc7\x31\x01\x12\x46\n\x11\x65xecution_timeout\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\x10\xe8\xc7\x31\x01\xfa\xc7\x31\x08\x30s-3600s\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12@\n\x07package\x18\t \x01(\x0b\x32-.yandex.cloud.serverless.functions.v1.PackageH\x00\x12!\n\x07\x63ontent\x18\n \x01(\x0c\x42\x0e\x8a\xc8\x31\n<=52428800H\x00\x12\x14\n\nversion_id\x18\x0b \x01(\tH\x00\x12\x8f\x01\n\x0b\x65nvironment\x18\x0c \x03(\x0b\x32S.yandex.cloud.serverless.functions.v1.CreateFunctionVersionRequest.EnvironmentEntryB%\x8a\xc8\x31\x06<=4096\xb2\xc8\x31\x17\x12\x15[a-zA-Z][a-zA-Z0-9_]*\x12!\n\x03tag\x18\r \x03(\tB\x14\xf2\xc7\x31\x10[a-z][-_0-9a-z]*\x12H\n\x0c\x63onnectivity\x18\x11 \x01(\x0b\x32\x32.yandex.cloud.serverless.functions.v1.Connectivity\x12|\n\x16named_service_accounts\x18\x0f \x03(\x0b\x32\\.yandex.cloud.serverless.functions.v1.CreateFunctionVersionRequest.NamedServiceAccountsEntry\x12=\n\x07secrets\x18\x12 \x03(\x0b\x32,.yandex.cloud.serverless.functions.v1.Secret\x12\x45\n\x0blog_options\x18\x13 \x01(\x0b\x32\x30.yandex.cloud.serverless.functions.v1.LogOptions\x12J\n\x0estorage_mounts\x18\x14 \x03(\x0b\x32\x32.yandex.cloud.serverless.functions.v1.StorageMount\x12\\\n\x17\x61sync_invocation_config\x18\x16 \x01(\x0b\x32;.yandex.cloud.serverless.functions.v1.AsyncInvocationConfig\x12\x12\n\ntmpfs_size\x18\x17 \x01(\x03\x12\x1d\n\x0b\x63oncurrency\x18\x18 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-16\x12;\n\x06mounts\x18\x19 \x03(\x0b\x32+.yandex.cloud.serverless.functions.v1.Mount\x1a\x32\n\x10\x45nvironmentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a;\n\x19NamedServiceAccountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x16\n\x0epackage_source\x12\x04\xc0\xc1\x31\x01J\x04\x08\x0e\x10\x0fJ\x04\x08\x10\x10\x11J\x04\x08\x15\x10\x16J\x04\x08\x08\x10\t\"<\n\x1d\x43reateFunctionVersionMetadata\x12\x1b\n\x13\x66unction_version_id\x18\x01 \x01(\t\"]\n\x15SetFunctionTagRequest\x12!\n\x13\x66unction_version_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12!\n\x03tag\x18\x02 \x01(\tB\x14\xf2\xc7\x31\x10[a-z][-_0-9a-z]*\"`\n\x18RemoveFunctionTagRequest\x12!\n\x13\x66unction_version_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12!\n\x03tag\x18\x02 \x01(\tB\x14\xf2\xc7\x31\x10[a-z][-_0-9a-z]*\"5\n\x16SetFunctionTagMetadata\x12\x1b\n\x13\x66unction_version_id\x18\x01 \x01(\t\"8\n\x19RemoveFunctionTagMetadata\x12\x1b\n\x13\x66unction_version_id\x18\x01 \x01(\t\"\xc1\x01\n\x1dListFunctionTagHistoryRequest\x12\x19\n\x0b\x66unction_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12+\n\x03tag\x18\x02 \x01(\tB\x1e\xf2\xc7\x31\x1a[a-z][-_0-9a-z]*|[$]latest\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\x80\x03\n\x1eListFunctionTagHistoryResponse\x12\x82\x01\n\x1b\x66unction_tag_history_record\x18\x01 \x03(\x0b\x32].yandex.cloud.serverless.functions.v1.ListFunctionTagHistoryResponse.FunctionTagHistoryRecord\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a\xbf\x01\n\x18\x46unctionTagHistoryRecord\x12\x13\n\x0b\x66unction_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66unction_version_id\x18\x03 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x32\n\x0e\x65\x66\x66\x65\x63tive_from\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x65\x66\x66\x65\x63tive_to\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"u\n\x1aListScalingPoliciesRequest\x12\x19\n\x0b\x66unction_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x85\x01\n\x1bListScalingPoliciesResponse\x12M\n\x10scaling_policies\x18\x01 \x03(\x0b\x32\x33.yandex.cloud.serverless.functions.v1.ScalingPolicy\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xef\x01\n\x17SetScalingPolicyRequest\x12\x19\n\x0b\x66unction_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x03tag\x18\x02 \x01(\tB\"\xe8\xc7\x31\x01\xf2\xc7\x31\x1a[a-z][-_0-9a-z]*|[$]latest\x12/\n\x1bprovisioned_instances_count\x18\x04 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12(\n\x14zone_instances_limit\x18\x05 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\'\n\x13zone_requests_limit\x18\x06 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000J\x04\x08\x03\x10\x04\"/\n\x18SetScalingPolicyMetadata\x12\x13\n\x0b\x66unction_id\x18\x01 \x01(\t\"h\n\x1aRemoveScalingPolicyRequest\x12\x19\n\x0b\x66unction_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x03tag\x18\x02 \x01(\tB\"\xe8\xc7\x31\x01\xf2\xc7\x31\x1a[a-z][-_0-9a-z]*|[$]latest\"2\n\x1bRemoveScalingPolicyMetadata\x12\x13\n\x0b\x66unction_id\x18\x01 \x01(\t2\xc4!\n\x0f\x46unctionService\x12\x9e\x01\n\x03Get\x12\x38.yandex.cloud.serverless.functions.v1.GetFunctionRequest\x1a..yandex.cloud.serverless.functions.v1.Function\"-\x82\xd3\xe4\x93\x02\'\x12%/functions/v1/functions/{function_id}\x12\xa0\x01\n\x04List\x12:.yandex.cloud.serverless.functions.v1.ListFunctionsRequest\x1a;.yandex.cloud.serverless.functions.v1.ListFunctionsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/functions/v1/functions\x12\xb2\x01\n\x06\x43reate\x12;.yandex.cloud.serverless.functions.v1.CreateFunctionRequest\x1a!.yandex.cloud.operation.Operation\"H\xb2\xd2*\"\n\x16\x43reateFunctionMetadata\x12\x08\x46unction\x82\xd3\xe4\x93\x02\x1c\"\x17/functions/v1/functions:\x01*\x12\xc0\x01\n\x06Update\x12;.yandex.cloud.serverless.functions.v1.UpdateFunctionRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*\"\n\x16UpdateFunctionMetadata\x12\x08\x46unction\x82\xd3\xe4\x93\x02*2%/functions/v1/functions/{function_id}:\x01*\x12\xca\x01\n\x06\x44\x65lete\x12;.yandex.cloud.serverless.functions.v1.DeleteFunctionRequest\x1a!.yandex.cloud.operation.Operation\"`\xb2\xd2*/\n\x16\x44\x65leteFunctionMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\'*%/functions/v1/functions/{function_id}\x12\xb2\x01\n\nGetVersion\x12?.yandex.cloud.serverless.functions.v1.GetFunctionVersionRequest\x1a-.yandex.cloud.serverless.functions.v1.Version\"4\x82\xd3\xe4\x93\x02.\x12,/functions/v1/versions/{function_version_id}\x12\xac\x01\n\x0fGetVersionByTag\x12\x44.yandex.cloud.serverless.functions.v1.GetFunctionVersionByTagRequest\x1a-.yandex.cloud.serverless.functions.v1.Version\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/functions/v1/versions:byTag\x12\xb7\x01\n\x0cListVersions\x12\x42.yandex.cloud.serverless.functions.v1.ListFunctionsVersionsRequest\x1a\x43.yandex.cloud.serverless.functions.v1.ListFunctionsVersionsResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/functions/v1/versions\x12\xe6\x01\n\rDeleteVersion\x12\x42.yandex.cloud.serverless.functions.v1.DeleteFunctionVersionRequest\x1a!.yandex.cloud.operation.Operation\"n\xb2\xd2*6\n\x1d\x44\x65leteFunctionVersionMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02.*,/functions/v1/versions/{function_version_id}\x12\xcd\x01\n\x06SetTag\x12;.yandex.cloud.serverless.functions.v1.SetFunctionTagRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*!\n\x16SetFunctionTagMetadata\x12\x07Version\x82\xd3\xe4\x93\x02\x38\"3/functions/v1/versions/{function_version_id}:setTag:\x01*\x12\xd9\x01\n\tRemoveTag\x12>.yandex.cloud.serverless.functions.v1.RemoveFunctionTagRequest\x1a!.yandex.cloud.operation.Operation\"i\xb2\xd2*$\n\x19RemoveFunctionTagMetadata\x12\x07Version\x82\xd3\xe4\x93\x02;\"6/functions/v1/versions/{function_version_id}:removeTag:\x01*\x12\xd5\x01\n\x0eListTagHistory\x12\x43.yandex.cloud.serverless.functions.v1.ListFunctionTagHistoryRequest\x1a\x44.yandex.cloud.serverless.functions.v1.ListFunctionTagHistoryResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/functions/v1/functions/{function_id}:tagHistory\x12\xc5\x01\n\rCreateVersion\x12\x42.yandex.cloud.serverless.functions.v1.CreateFunctionVersionRequest\x1a!.yandex.cloud.operation.Operation\"M\xb2\xd2*(\n\x1d\x43reateFunctionVersionMetadata\x12\x07Version\x82\xd3\xe4\x93\x02\x1b\"\x16/functions/v1/versions:\x01*\x12\xa5\x01\n\x0cListRuntimes\x12\x39.yandex.cloud.serverless.functions.v1.ListRuntimesRequest\x1a:.yandex.cloud.serverless.functions.v1.ListRuntimesResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/functions/v1/runtimes\x12\xd5\x01\n\x0eListOperations\x12\x43.yandex.cloud.serverless.functions.v1.ListFunctionOperationsRequest\x1a\x44.yandex.cloud.serverless.functions.v1.ListFunctionOperationsResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/functions/v1/functions/{function_id}/operations\x12\xb7\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/functions/v1/functions/{resource_id}:listAccessBindings\x12\xe6\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02<\"7/functions/v1/functions/{resource_id}:setAccessBindings:\x01*\x12\xf3\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02?\":/functions/v1/functions/{resource_id}:updateAccessBindings:\x01*\x12\xd9\x01\n\x13ListScalingPolicies\x12@.yandex.cloud.serverless.functions.v1.ListScalingPoliciesRequest\x1a\x41.yandex.cloud.serverless.functions.v1.ListScalingPoliciesResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/functions/v1/functions/{function_id}/scalingPolicies\x12\xe4\x01\n\x10SetScalingPolicy\x12=.yandex.cloud.serverless.functions.v1.SetScalingPolicyRequest\x1a!.yandex.cloud.operation.Operation\"n\xb2\xd2*)\n\x18SetScalingPolicyMetadata\x12\rScalingPolicy\x82\xd3\xe4\x93\x02;\"6/functions/v1/functions/{function_id}:setScalingPolicy:\x01*\x12\xf8\x01\n\x13RemoveScalingPolicy\x12@.yandex.cloud.serverless.functions.v1.RemoveScalingPolicyRequest\x1a!.yandex.cloud.operation.Operation\"|\xb2\xd2*4\n\x1bRemoveScalingPolicyMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02>\"9/functions/v1/functions/{function_id}:removeScalingPolicy:\x01*B~\n(yandex.cloud.api.serverless.functions.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/functions/v1;functionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.functions.v1.function_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.serverless.functions.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/functions/v1;functions'
  _GETFUNCTIONREQUEST.fields_by_name['function_id']._options = None
  _GETFUNCTIONREQUEST.fields_by_name['function_id']._serialized_options = b'\350\3071\001'
  _GETFUNCTIONVERSIONREQUEST.fields_by_name['function_version_id']._options = None
  _GETFUNCTIONVERSIONREQUEST.fields_by_name['function_version_id']._serialized_options = b'\350\3071\001'
  _GETFUNCTIONVERSIONBYTAGREQUEST.fields_by_name['function_id']._options = None
  _GETFUNCTIONVERSIONBYTAGREQUEST.fields_by_name['function_id']._serialized_options = b'\350\3071\001'
  _GETFUNCTIONVERSIONBYTAGREQUEST.fields_by_name['tag']._options = None
  _GETFUNCTIONVERSIONBYTAGREQUEST.fields_by_name['tag']._serialized_options = b'\362\3071\032[a-z][-_0-9a-z]*|[$]latest'
  _LISTFUNCTIONSREQUEST.fields_by_name['folder_id']._options = None
  _LISTFUNCTIONSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _CREATEFUNCTIONREQUEST_LABELSENTRY._options = None
  _CREATEFUNCTIONREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEFUNCTIONREQUEST.fields_by_name['folder_id']._options = None
  _CREATEFUNCTIONREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _CREATEFUNCTIONREQUEST.fields_by_name['name']._options = None
  _CREATEFUNCTIONREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATEFUNCTIONREQUEST.fields_by_name['description']._options = None
  _CREATEFUNCTIONREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEFUNCTIONREQUEST.fields_by_name['labels']._options = None
  _CREATEFUNCTIONREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _UPDATEFUNCTIONREQUEST_LABELSENTRY._options = None
  _UPDATEFUNCTIONREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEFUNCTIONREQUEST.fields_by_name['function_id']._options = None
  _UPDATEFUNCTIONREQUEST.fields_by_name['function_id']._serialized_options = b'\350\3071\001'
  _UPDATEFUNCTIONREQUEST.fields_by_name['name']._options = None
  _UPDATEFUNCTIONREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATEFUNCTIONREQUEST.fields_by_name['description']._options = None
  _UPDATEFUNCTIONREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEFUNCTIONREQUEST.fields_by_name['labels']._options = None
  _UPDATEFUNCTIONREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _DELETEFUNCTIONREQUEST.fields_by_name['function_id']._options = None
  _DELETEFUNCTIONREQUEST.fields_by_name['function_id']._serialized_options = b'\350\3071\001'
  _DELETEFUNCTIONVERSIONREQUEST.fields_by_name['function_version_id']._options = None
  _DELETEFUNCTIONVERSIONREQUEST.fields_by_name['function_version_id']._serialized_options = b'\350\3071\001'
  _LISTFUNCTIONSVERSIONSREQUEST.oneofs_by_name['id']._options = None
  _LISTFUNCTIONSVERSIONSREQUEST.oneofs_by_name['id']._serialized_options = b'\300\3011\001'
  _LISTFUNCTIONSVERSIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTFUNCTIONSVERSIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTFUNCTIONSVERSIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTFUNCTIONSVERSIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTFUNCTIONSVERSIONSREQUEST.fields_by_name['filter']._options = None
  _LISTFUNCTIONSVERSIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTFUNCTIONOPERATIONSREQUEST.fields_by_name['function_id']._options = None
  _LISTFUNCTIONOPERATIONSREQUEST.fields_by_name['function_id']._serialized_options = b'\350\3071\001'
  _LISTFUNCTIONOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTFUNCTIONOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTFUNCTIONOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTFUNCTIONOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTFUNCTIONOPERATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTFUNCTIONOPERATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATEFUNCTIONVERSIONREQUEST_ENVIRONMENTENTRY._options = None
  _CREATEFUNCTIONVERSIONREQUEST_ENVIRONMENTENTRY._serialized_options = b'8\001'
  _CREATEFUNCTIONVERSIONREQUEST_NAMEDSERVICEACCOUNTSENTRY._options = None
  _CREATEFUNCTIONVERSIONREQUEST_NAMEDSERVICEACCOUNTSENTRY._serialized_options = b'8\001'
  _CREATEFUNCTIONVERSIONREQUEST.oneofs_by_name['package_source']._options = None
  _CREATEFUNCTIONVERSIONREQUEST.oneofs_by_name['package_source']._serialized_options = b'\300\3011\001'
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['function_id']._options = None
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['function_id']._serialized_options = b'\350\3071\001'
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['runtime']._options = None
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['runtime']._serialized_options = b'\350\3071\001'
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['description']._options = None
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\0050-256'
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['entrypoint']._options = None
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['entrypoint']._serialized_options = b'\350\3071\001'
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['resources']._options = None
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['resources']._serialized_options = b'\350\3071\001'
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['execution_timeout']._options = None
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['execution_timeout']._serialized_options = b'\350\3071\001\372\3071\0100s-3600s'
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['content']._options = None
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['content']._serialized_options = b'\212\3101\n<=52428800'
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['environment']._options = None
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['environment']._serialized_options = b'\212\3101\006<=4096\262\3101\027\022\025[a-zA-Z][a-zA-Z0-9_]*'
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['tag']._options = None
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['tag']._serialized_options = b'\362\3071\020[a-z][-_0-9a-z]*'
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['concurrency']._options = None
  _CREATEFUNCTIONVERSIONREQUEST.fields_by_name['concurrency']._serialized_options = b'\372\3071\0040-16'
  _SETFUNCTIONTAGREQUEST.fields_by_name['function_version_id']._options = None
  _SETFUNCTIONTAGREQUEST.fields_by_name['function_version_id']._serialized_options = b'\350\3071\001'
  _SETFUNCTIONTAGREQUEST.fields_by_name['tag']._options = None
  _SETFUNCTIONTAGREQUEST.fields_by_name['tag']._serialized_options = b'\362\3071\020[a-z][-_0-9a-z]*'
  _REMOVEFUNCTIONTAGREQUEST.fields_by_name['function_version_id']._options = None
  _REMOVEFUNCTIONTAGREQUEST.fields_by_name['function_version_id']._serialized_options = b'\350\3071\001'
  _REMOVEFUNCTIONTAGREQUEST.fields_by_name['tag']._options = None
  _REMOVEFUNCTIONTAGREQUEST.fields_by_name['tag']._serialized_options = b'\362\3071\020[a-z][-_0-9a-z]*'
  _LISTFUNCTIONTAGHISTORYREQUEST.fields_by_name['function_id']._options = None
  _LISTFUNCTIONTAGHISTORYREQUEST.fields_by_name['function_id']._serialized_options = b'\350\3071\001'
  _LISTFUNCTIONTAGHISTORYREQUEST.fields_by_name['tag']._options = None
  _LISTFUNCTIONTAGHISTORYREQUEST.fields_by_name['tag']._serialized_options = b'\362\3071\032[a-z][-_0-9a-z]*|[$]latest'
  _LISTFUNCTIONTAGHISTORYREQUEST.fields_by_name['page_size']._options = None
  _LISTFUNCTIONTAGHISTORYREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTFUNCTIONTAGHISTORYREQUEST.fields_by_name['page_token']._options = None
  _LISTFUNCTIONTAGHISTORYREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTFUNCTIONTAGHISTORYREQUEST.fields_by_name['filter']._options = None
  _LISTFUNCTIONTAGHISTORYREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTSCALINGPOLICIESREQUEST.fields_by_name['function_id']._options = None
  _LISTSCALINGPOLICIESREQUEST.fields_by_name['function_id']._serialized_options = b'\350\3071\001'
  _LISTSCALINGPOLICIESREQUEST.fields_by_name['page_size']._options = None
  _LISTSCALINGPOLICIESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTSCALINGPOLICIESREQUEST.fields_by_name['page_token']._options = None
  _LISTSCALINGPOLICIESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _SETSCALINGPOLICYREQUEST.fields_by_name['function_id']._options = None
  _SETSCALINGPOLICYREQUEST.fields_by_name['function_id']._serialized_options = b'\350\3071\001'
  _SETSCALINGPOLICYREQUEST.fields_by_name['tag']._options = None
  _SETSCALINGPOLICYREQUEST.fields_by_name['tag']._serialized_options = b'\350\3071\001\362\3071\032[a-z][-_0-9a-z]*|[$]latest'
  _SETSCALINGPOLICYREQUEST.fields_by_name['provisioned_instances_count']._options = None
  _SETSCALINGPOLICYREQUEST.fields_by_name['provisioned_instances_count']._serialized_options = b'\372\3071\0060-1000'
  _SETSCALINGPOLICYREQUEST.fields_by_name['zone_instances_limit']._options = None
  _SETSCALINGPOLICYREQUEST.fields_by_name['zone_instances_limit']._serialized_options = b'\372\3071\0060-1000'
  _SETSCALINGPOLICYREQUEST.fields_by_name['zone_requests_limit']._options = None
  _SETSCALINGPOLICYREQUEST.fields_by_name['zone_requests_limit']._serialized_options = b'\372\3071\0060-1000'
  _REMOVESCALINGPOLICYREQUEST.fields_by_name['function_id']._options = None
  _REMOVESCALINGPOLICYREQUEST.fields_by_name['function_id']._serialized_options = b'\350\3071\001'
  _REMOVESCALINGPOLICYREQUEST.fields_by_name['tag']._options = None
  _REMOVESCALINGPOLICYREQUEST.fields_by_name['tag']._serialized_options = b'\350\3071\001\362\3071\032[a-z][-_0-9a-z]*|[$]latest'
  _FUNCTIONSERVICE.methods_by_name['Get']._options = None
  _FUNCTIONSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\'\022%/functions/v1/functions/{function_id}'
  _FUNCTIONSERVICE.methods_by_name['List']._options = None
  _FUNCTIONSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\031\022\027/functions/v1/functions'
  _FUNCTIONSERVICE.methods_by_name['Create']._options = None
  _FUNCTIONSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateFunctionMetadata\022\010Function\202\323\344\223\002\034\"\027/functions/v1/functions:\001*'
  _FUNCTIONSERVICE.methods_by_name['Update']._options = None
  _FUNCTIONSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateFunctionMetadata\022\010Function\202\323\344\223\002*2%/functions/v1/functions/{function_id}:\001*'
  _FUNCTIONSERVICE.methods_by_name['Delete']._options = None
  _FUNCTIONSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteFunctionMetadata\022\025google.protobuf.Empty\202\323\344\223\002\'*%/functions/v1/functions/{function_id}'
  _FUNCTIONSERVICE.methods_by_name['GetVersion']._options = None
  _FUNCTIONSERVICE.methods_by_name['GetVersion']._serialized_options = b'\202\323\344\223\002.\022,/functions/v1/versions/{function_version_id}'
  _FUNCTIONSERVICE.methods_by_name['GetVersionByTag']._options = None
  _FUNCTIONSERVICE.methods_by_name['GetVersionByTag']._serialized_options = b'\202\323\344\223\002\036\022\034/functions/v1/versions:byTag'
  _FUNCTIONSERVICE.methods_by_name['ListVersions']._options = None
  _FUNCTIONSERVICE.methods_by_name['ListVersions']._serialized_options = b'\202\323\344\223\002\030\022\026/functions/v1/versions'
  _FUNCTIONSERVICE.methods_by_name['DeleteVersion']._options = None
  _FUNCTIONSERVICE.methods_by_name['DeleteVersion']._serialized_options = b'\262\322*6\n\035DeleteFunctionVersionMetadata\022\025google.protobuf.Empty\202\323\344\223\002.*,/functions/v1/versions/{function_version_id}'
  _FUNCTIONSERVICE.methods_by_name['SetTag']._options = None
  _FUNCTIONSERVICE.methods_by_name['SetTag']._serialized_options = b'\262\322*!\n\026SetFunctionTagMetadata\022\007Version\202\323\344\223\0028\"3/functions/v1/versions/{function_version_id}:setTag:\001*'
  _FUNCTIONSERVICE.methods_by_name['RemoveTag']._options = None
  _FUNCTIONSERVICE.methods_by_name['RemoveTag']._serialized_options = b'\262\322*$\n\031RemoveFunctionTagMetadata\022\007Version\202\323\344\223\002;\"6/functions/v1/versions/{function_version_id}:removeTag:\001*'
  _FUNCTIONSERVICE.methods_by_name['ListTagHistory']._options = None
  _FUNCTIONSERVICE.methods_by_name['ListTagHistory']._serialized_options = b'\202\323\344\223\0022\0220/functions/v1/functions/{function_id}:tagHistory'
  _FUNCTIONSERVICE.methods_by_name['CreateVersion']._options = None
  _FUNCTIONSERVICE.methods_by_name['CreateVersion']._serialized_options = b'\262\322*(\n\035CreateFunctionVersionMetadata\022\007Version\202\323\344\223\002\033\"\026/functions/v1/versions:\001*'
  _FUNCTIONSERVICE.methods_by_name['ListRuntimes']._options = None
  _FUNCTIONSERVICE.methods_by_name['ListRuntimes']._serialized_options = b'\202\323\344\223\002\030\022\026/functions/v1/runtimes'
  _FUNCTIONSERVICE.methods_by_name['ListOperations']._options = None
  _FUNCTIONSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0022\0220/functions/v1/functions/{function_id}/operations'
  _FUNCTIONSERVICE.methods_by_name['ListAccessBindings']._options = None
  _FUNCTIONSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002:\0228/functions/v1/functions/{resource_id}:listAccessBindings'
  _FUNCTIONSERVICE.methods_by_name['SetAccessBindings']._options = None
  _FUNCTIONSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002<\"7/functions/v1/functions/{resource_id}:setAccessBindings:\001*'
  _FUNCTIONSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _FUNCTIONSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002?\":/functions/v1/functions/{resource_id}:updateAccessBindings:\001*'
  _FUNCTIONSERVICE.methods_by_name['ListScalingPolicies']._options = None
  _FUNCTIONSERVICE.methods_by_name['ListScalingPolicies']._serialized_options = b'\202\323\344\223\0027\0225/functions/v1/functions/{function_id}/scalingPolicies'
  _FUNCTIONSERVICE.methods_by_name['SetScalingPolicy']._options = None
  _FUNCTIONSERVICE.methods_by_name['SetScalingPolicy']._serialized_options = b'\262\322*)\n\030SetScalingPolicyMetadata\022\rScalingPolicy\202\323\344\223\002;\"6/functions/v1/functions/{function_id}:setScalingPolicy:\001*'
  _FUNCTIONSERVICE.methods_by_name['RemoveScalingPolicy']._options = None
  _FUNCTIONSERVICE.methods_by_name['RemoveScalingPolicy']._serialized_options = b'\262\322*4\n\033RemoveScalingPolicyMetadata\022\025google.protobuf.Empty\202\323\344\223\002>\"9/functions/v1/functions/{function_id}:removeScalingPolicy:\001*'
  _globals['_GETFUNCTIONREQUEST']._serialized_start=422
  _globals['_GETFUNCTIONREQUEST']._serialized_end=469
  _globals['_GETFUNCTIONVERSIONREQUEST']._serialized_start=471
  _globals['_GETFUNCTIONVERSIONREQUEST']._serialized_end=533
  _globals['_GETFUNCTIONVERSIONBYTAGREQUEST']._serialized_start=535
  _globals['_GETFUNCTIONVERSIONBYTAGREQUEST']._serialized_end=639
  _globals['_LISTFUNCTIONSREQUEST']._serialized_start=641
  _globals['_LISTFUNCTIONSREQUEST']._serialized_end=743
  _globals['_LISTFUNCTIONSRESPONSE']._serialized_start=745
  _globals['_LISTFUNCTIONSRESPONSE']._serialized_end=860
  _globals['_CREATEFUNCTIONREQUEST']._serialized_start=863
  _globals['_CREATEFUNCTIONREQUEST']._serialized_end=1198
  _globals['_CREATEFUNCTIONREQUEST_LABELSENTRY']._serialized_start=1153
  _globals['_CREATEFUNCTIONREQUEST_LABELSENTRY']._serialized_end=1198
  _globals['_CREATEFUNCTIONMETADATA']._serialized_start=1200
  _globals['_CREATEFUNCTIONMETADATA']._serialized_end=1245
  _globals['_UPDATEFUNCTIONREQUEST']._serialized_start=1248
  _globals['_UPDATEFUNCTIONREQUEST']._serialized_end=1634
  _globals['_UPDATEFUNCTIONREQUEST_LABELSENTRY']._serialized_start=1153
  _globals['_UPDATEFUNCTIONREQUEST_LABELSENTRY']._serialized_end=1198
  _globals['_UPDATEFUNCTIONMETADATA']._serialized_start=1636
  _globals['_UPDATEFUNCTIONMETADATA']._serialized_end=1681
  _globals['_DELETEFUNCTIONREQUEST']._serialized_start=1683
  _globals['_DELETEFUNCTIONREQUEST']._serialized_end=1733
  _globals['_DELETEFUNCTIONMETADATA']._serialized_start=1735
  _globals['_DELETEFUNCTIONMETADATA']._serialized_end=1780
  _globals['_DELETEFUNCTIONVERSIONREQUEST']._serialized_start=1782
  _globals['_DELETEFUNCTIONVERSIONREQUEST']._serialized_end=1868
  _globals['_DELETEFUNCTIONVERSIONMETADATA']._serialized_start=1870
  _globals['_DELETEFUNCTIONVERSIONMETADATA']._serialized_end=1936
  _globals['_LISTRUNTIMESREQUEST']._serialized_start=1938
  _globals['_LISTRUNTIMESREQUEST']._serialized_end=1959
  _globals['_LISTRUNTIMESRESPONSE']._serialized_start=1961
  _globals['_LISTRUNTIMESRESPONSE']._serialized_end=2001
  _globals['_LISTFUNCTIONSVERSIONSREQUEST']._serialized_start=2004
  _globals['_LISTFUNCTIONSVERSIONSREQUEST']._serialized_end=2180
  _globals['_LISTFUNCTIONSVERSIONSRESPONSE']._serialized_start=2182
  _globals['_LISTFUNCTIONSVERSIONSRESPONSE']._serialized_end=2303
  _globals['_LISTFUNCTIONOPERATIONSREQUEST']._serialized_start=2306
  _globals['_LISTFUNCTIONOPERATIONSREQUEST']._serialized_end=2454
  _globals['_LISTFUNCTIONOPERATIONSRESPONSE']._serialized_start=2456
  _globals['_LISTFUNCTIONOPERATIONSRESPONSE']._serialized_end=2568
  _globals['_CREATEFUNCTIONVERSIONREQUEST']._serialized_start=2571
  _globals['_CREATEFUNCTIONVERSIONREQUEST']._serialized_end=3964
  _globals['_CREATEFUNCTIONVERSIONREQUEST_ENVIRONMENTENTRY']._serialized_start=3805
  _globals['_CREATEFUNCTIONVERSIONREQUEST_ENVIRONMENTENTRY']._serialized_end=3855
  _globals['_CREATEFUNCTIONVERSIONREQUEST_NAMEDSERVICEACCOUNTSENTRY']._serialized_start=3857
  _globals['_CREATEFUNCTIONVERSIONREQUEST_NAMEDSERVICEACCOUNTSENTRY']._serialized_end=3916
  _globals['_CREATEFUNCTIONVERSIONMETADATA']._serialized_start=3966
  _globals['_CREATEFUNCTIONVERSIONMETADATA']._serialized_end=4026
  _globals['_SETFUNCTIONTAGREQUEST']._serialized_start=4028
  _globals['_SETFUNCTIONTAGREQUEST']._serialized_end=4121
  _globals['_REMOVEFUNCTIONTAGREQUEST']._serialized_start=4123
  _globals['_REMOVEFUNCTIONTAGREQUEST']._serialized_end=4219
  _globals['_SETFUNCTIONTAGMETADATA']._serialized_start=4221
  _globals['_SETFUNCTIONTAGMETADATA']._serialized_end=4274
  _globals['_REMOVEFUNCTIONTAGMETADATA']._serialized_start=4276
  _globals['_REMOVEFUNCTIONTAGMETADATA']._serialized_end=4332
  _globals['_LISTFUNCTIONTAGHISTORYREQUEST']._serialized_start=4335
  _globals['_LISTFUNCTIONTAGHISTORYREQUEST']._serialized_end=4528
  _globals['_LISTFUNCTIONTAGHISTORYRESPONSE']._serialized_start=4531
  _globals['_LISTFUNCTIONTAGHISTORYRESPONSE']._serialized_end=4915
  _globals['_LISTFUNCTIONTAGHISTORYRESPONSE_FUNCTIONTAGHISTORYRECORD']._serialized_start=4724
  _globals['_LISTFUNCTIONTAGHISTORYRESPONSE_FUNCTIONTAGHISTORYRECORD']._serialized_end=4915
  _globals['_LISTSCALINGPOLICIESREQUEST']._serialized_start=4917
  _globals['_LISTSCALINGPOLICIESREQUEST']._serialized_end=5034
  _globals['_LISTSCALINGPOLICIESRESPONSE']._serialized_start=5037
  _globals['_LISTSCALINGPOLICIESRESPONSE']._serialized_end=5170
  _globals['_SETSCALINGPOLICYREQUEST']._serialized_start=5173
  _globals['_SETSCALINGPOLICYREQUEST']._serialized_end=5412
  _globals['_SETSCALINGPOLICYMETADATA']._serialized_start=5414
  _globals['_SETSCALINGPOLICYMETADATA']._serialized_end=5461
  _globals['_REMOVESCALINGPOLICYREQUEST']._serialized_start=5463
  _globals['_REMOVESCALINGPOLICYREQUEST']._serialized_end=5567
  _globals['_REMOVESCALINGPOLICYMETADATA']._serialized_start=5569
  _globals['_REMOVESCALINGPOLICYMETADATA']._serialized_end=5619
  _globals['_FUNCTIONSERVICE']._serialized_start=5622
  _globals['_FUNCTIONSERVICE']._serialized_end=9914
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.video.v1.subtitle_pb2
import yandex.cloud.video.v1.subtitle_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SubtitleServiceStub:
    """Subtitle management service."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.GetSubtitleRequest,
        yandex.cloud.video.v1.subtitle_pb2.Subtitle,
    ]
    """Return a specific subtitle."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.ListSubtitlesRequest,
        yandex.cloud.video.v1.subtitle_service_pb2.ListSubtitlesResponse,
    ]
    """List subtitles."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.CreateSubtitleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create a new subtitle."""

    GenerateUploadURL: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.GenerateSubtitleUploadURLRequest,
        yandex.cloud.video.v1.subtitle_service_pb2.GenerateSubtitleUploadURLResponse,
    ]
    """Generate an upload URL to add a new subtitle file."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.DeleteSubtitleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete a specific subtitle."""

class SubtitleServiceAsyncStub:
    """Subtitle management service."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.GetSubtitleRequest,
        yandex.cloud.video.v1.subtitle_pb2.Subtitle,
    ]
    """Return a specific subtitle."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.ListSubtitlesRequest,
        yandex.cloud.video.v1.subtitle_service_pb2.ListSubtitlesResponse,
    ]
    """List subtitles."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.CreateSubtitleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create a new subtitle."""

    GenerateUploadURL: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.GenerateSubtitleUploadURLRequest,
        yandex.cloud.video.v1.subtitle_service_pb2.GenerateSubtitleUploadURLResponse,
    ]
    """Generate an upload URL to add a new subtitle file."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.DeleteSubtitleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete a specific subtitle."""

class SubtitleServiceServicer(metaclass=abc.ABCMeta):
    """Subtitle management service."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.video.v1.subtitle_service_pb2.GetSubtitleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.subtitle_pb2.Subtitle, collections.abc.Awaitable[yandex.cloud.video.v1.subtitle_pb2.Subtitle]]:
        """Return a specific subtitle."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.video.v1.subtitle_service_pb2.ListSubtitlesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.subtitle_service_pb2.ListSubtitlesResponse, collections.abc.Awaitable[yandex.cloud.video.v1.subtitle_service_pb2.ListSubtitlesResponse]]:
        """List subtitles."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.video.v1.subtitle_service_pb2.CreateSubtitleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Create a new subtitle."""

    @abc.abstractmethod
    def GenerateUploadURL(
        self,
        request: yandex.cloud.video.v1.subtitle_service_pb2.GenerateSubtitleUploadURLRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.subtitle_service_pb2.GenerateSubtitleUploadURLResponse, collections.abc.Awaitable[yandex.cloud.video.v1.subtitle_service_pb2.GenerateSubtitleUploadURLResponse]]:
        """Generate an upload URL to add a new subtitle file."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.video.v1.subtitle_service_pb2.DeleteSubtitleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete a specific subtitle."""

def add_SubtitleServiceServicer_to_server(servicer: SubtitleServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Project(google.protobuf.message.Message):
    """A Project resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Settings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Ide:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _IdeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Project.Settings._Ide.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            IDE_UNSPECIFIED: Project.Settings._Ide.ValueType  # 0
            JUPYTER_LAB: Project.Settings._Ide.ValueType  # 1
            """Project running on JupyterLab IDE."""

        class Ide(_Ide, metaclass=_IdeEnumTypeWrapper): ...
        IDE_UNSPECIFIED: Project.Settings.Ide.ValueType  # 0
        JUPYTER_LAB: Project.Settings.Ide.ValueType  # 1
        """Project running on JupyterLab IDE."""

        class _StaleExecutionTimeoutMode:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _StaleExecutionTimeoutModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Project.Settings._StaleExecutionTimeoutMode.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            STALE_EXECUTION_TIMEOUT_MODE_UNSPECIFIED: Project.Settings._StaleExecutionTimeoutMode.ValueType  # 0
            ONE_HOUR: Project.Settings._StaleExecutionTimeoutMode.ValueType  # 1
            """Setting to automatically stop stale execution after one hour with low consumption."""
            THREE_HOURS: Project.Settings._StaleExecutionTimeoutMode.ValueType  # 2
            """Setting to automatically stop stale execution after three hours with low consumption."""
            NO_TIMEOUT: Project.Settings._StaleExecutionTimeoutMode.ValueType  # 3
            """Setting to never automatically stop stale executions."""

        class StaleExecutionTimeoutMode(_StaleExecutionTimeoutMode, metaclass=_StaleExecutionTimeoutModeEnumTypeWrapper): ...
        STALE_EXECUTION_TIMEOUT_MODE_UNSPECIFIED: Project.Settings.StaleExecutionTimeoutMode.ValueType  # 0
        ONE_HOUR: Project.Settings.StaleExecutionTimeoutMode.ValueType  # 1
        """Setting to automatically stop stale execution after one hour with low consumption."""
        THREE_HOURS: Project.Settings.StaleExecutionTimeoutMode.ValueType  # 2
        """Setting to automatically stop stale execution after three hours with low consumption."""
        NO_TIMEOUT: Project.Settings.StaleExecutionTimeoutMode.ValueType  # 3
        """Setting to never automatically stop stale executions."""

        SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
        SUBNET_ID_FIELD_NUMBER: builtins.int
        DATA_PROC_CLUSTER_ID_FIELD_NUMBER: builtins.int
        SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
        EARLY_ACCESS_FIELD_NUMBER: builtins.int
        IDE_FIELD_NUMBER: builtins.int
        DEFAULT_FOLDER_ID_FIELD_NUMBER: builtins.int
        STALE_EXEC_TIMEOUT_MODE_FIELD_NUMBER: builtins.int
        VM_INACTIVITY_TIMEOUT_FIELD_NUMBER: builtins.int
        DEFAULT_DEDICATED_SPEC_FIELD_NUMBER: builtins.int
        service_account_id: builtins.str
        """ID of the service account, on whose behalf all operations with clusters will be performed."""
        subnet_id: builtins.str
        """ID of the subnet where the DataProc cluster resides.
        Currently only subnets created in the availability zone ru-central1-a are supported.
        """
        data_proc_cluster_id: builtins.str
        """ID of the DataProc cluster."""
        early_access: builtins.bool
        """Is early access preview enabled for the project."""
        ide: global___Project.Settings.Ide.ValueType
        """Project IDE."""
        default_folder_id: builtins.str
        """Default project folder ID."""
        stale_exec_timeout_mode: global___Project.Settings.StaleExecutionTimeoutMode.ValueType
        """Timeout to automatically stop stale executions."""
        default_dedicated_spec: builtins.str
        """Default VM configuration for DEDICATED mode."""
        @property
        def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Network interfaces security groups."""

        @property
        def vm_inactivity_timeout(self) -> google.protobuf.duration_pb2.Duration:
            """Timeout for VM deallocation."""

        def __init__(
            self,
            *,
            service_account_id: builtins.str = ...,
            subnet_id: builtins.str = ...,
            data_proc_cluster_id: builtins.str = ...,
            security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
            early_access: builtins.bool = ...,
            ide: global___Project.Settings.Ide.ValueType = ...,
            default_folder_id: builtins.str = ...,
            stale_exec_timeout_mode: global___Project.Settings.StaleExecutionTimeoutMode.ValueType = ...,
            vm_inactivity_timeout: google.protobuf.duration_pb2.Duration | None = ...,
            default_dedicated_spec: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["vm_inactivity_timeout", b"vm_inactivity_timeout"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["data_proc_cluster_id", b"data_proc_cluster_id", "default_dedicated_spec", b"default_dedicated_spec", "default_folder_id", b"default_folder_id", "early_access", b"early_access", "ide", b"ide", "security_group_ids", b"security_group_ids", "service_account_id", b"service_account_id", "stale_exec_timeout_mode", b"stale_exec_timeout_mode", "subnet_id", b"subnet_id", "vm_inactivity_timeout", b"vm_inactivity_timeout"]) -> None: ...

    @typing.final
    class Limits(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MAX_UNITS_PER_HOUR_FIELD_NUMBER: builtins.int
        MAX_UNITS_PER_EXECUTION_FIELD_NUMBER: builtins.int
        @property
        def max_units_per_hour(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """The number of units that can be spent per hour."""

        @property
        def max_units_per_execution(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """The number of units that can be spent on the one execution."""

        def __init__(
            self,
            *,
            max_units_per_hour: google.protobuf.wrappers_pb2.Int64Value | None = ...,
            max_units_per_execution: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["max_units_per_execution", b"max_units_per_execution", "max_units_per_hour", b"max_units_per_hour"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["max_units_per_execution", b"max_units_per_execution", "max_units_per_hour", b"max_units_per_hour"]) -> None: ...

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CREATED_BY_ID_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    LIMITS_FIELD_NUMBER: builtins.int
    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the project."""
    name: builtins.str
    """Name of the project. 1-63 characters long."""
    description: builtins.str
    """Description of the project. 0-256 characters long."""
    created_by_id: builtins.str
    community_id: builtins.str
    """ID of the community that the project belongs to."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def settings(self) -> global___Project.Settings:
        """Settings of the project."""

    @property
    def limits(self) -> global___Project.Limits:
        """Limits of the project."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        created_by_id: builtins.str = ...,
        settings: global___Project.Settings | None = ...,
        limits: global___Project.Limits | None = ...,
        community_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "limits", b"limits", "settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["community_id", b"community_id", "created_at", b"created_at", "created_by_id", b"created_by_id", "description", b"description", "id", b"id", "labels", b"labels", "limits", b"limits", "name", b"name", "settings", b"settings"]) -> None: ...

global___Project = Project



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.billing.v1.customer_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListCustomersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESELLER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    reseller_id: builtins.str
    """ID of the reseller."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListCustomersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListCustomersResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        reseller_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "reseller_id", b"reseller_id"]) -> None: ...

global___ListCustomersRequest = ListCustomersRequest

@typing.final
class ListCustomersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUSTOMERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListCustomersRequest.page_size], use
    [next_page_token] as the value
    for the [ListCustomersRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def customers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.v1.customer_pb2.Customer]:
        """List of customers."""

    def __init__(
        self,
        *,
        customers: collections.abc.Iterable[yandex.cloud.billing.v1.customer_pb2.Customer] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["customers", b"customers", "next_page_token", b"next_page_token"]) -> None: ...

global___ListCustomersResponse = ListCustomersResponse

@typing.final
class InviteCustomerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESELLER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    INVITATION_EMAIL_FIELD_NUMBER: builtins.int
    PERSON_FIELD_NUMBER: builtins.int
    reseller_id: builtins.str
    """Billing account ID of the reseller that the customer will be associated with."""
    name: builtins.str
    """Name of the customer."""
    invitation_email: builtins.str
    """Customer email to send invitation to."""
    @property
    def person(self) -> yandex.cloud.billing.v1.customer_pb2.CustomerPerson:
        """Person of the customer."""

    def __init__(
        self,
        *,
        reseller_id: builtins.str = ...,
        name: builtins.str = ...,
        invitation_email: builtins.str = ...,
        person: yandex.cloud.billing.v1.customer_pb2.CustomerPerson | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["person", b"person"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["invitation_email", b"invitation_email", "name", b"name", "person", b"person", "reseller_id", b"reseller_id"]) -> None: ...

global___InviteCustomerRequest = InviteCustomerRequest

@typing.final
class CreateResellerServedCustomerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESELLER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PERSON_FIELD_NUMBER: builtins.int
    reseller_id: builtins.str
    """ID of the reseller that customer will be associated with.</br>

    Value must match either one of the three regular expressions:
    </br>- `^([0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12})$`
    </br>- `^([0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{32})$`
    </br>- `^[a-z][-a-zA-Z0-9.]{0,48}[a-zA-Z0-9]$`
    """
    name: builtins.str
    """Name of the customer.

    String length is not limited.
    """
    @property
    def person(self) -> yandex.cloud.billing.v1.customer_pb2.CustomerPerson:
        """Person of the customer."""

    def __init__(
        self,
        *,
        reseller_id: builtins.str = ...,
        name: builtins.str = ...,
        person: yandex.cloud.billing.v1.customer_pb2.CustomerPerson | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["person", b"person"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "person", b"person", "reseller_id", b"reseller_id"]) -> None: ...

global___CreateResellerServedCustomerRequest = CreateResellerServedCustomerRequest

@typing.final
class ActivateCustomerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    customer_id: builtins.str
    """ID of the customer.
    To get the customer ID, use [CustomerService.List] request.
    """
    def __init__(
        self,
        *,
        customer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["customer_id", b"customer_id"]) -> None: ...

global___ActivateCustomerRequest = ActivateCustomerRequest

@typing.final
class SuspendCustomerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    customer_id: builtins.str
    """ID of the customer.
    To get the customer ID, use [CustomerService.List] request.
    """
    def __init__(
        self,
        *,
        customer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["customer_id", b"customer_id"]) -> None: ...

global___SuspendCustomerRequest = SuspendCustomerRequest

@typing.final
class CustomerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESELLER_ID_FIELD_NUMBER: builtins.int
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    reseller_id: builtins.str
    """ID of the reseller."""
    customer_id: builtins.str
    """ID of the customer."""
    def __init__(
        self,
        *,
        reseller_id: builtins.str = ...,
        customer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["customer_id", b"customer_id", "reseller_id", b"reseller_id"]) -> None: ...

global___CustomerMetadata = CustomerMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PromptTruncationOptions(google.protobuf.message.Message):
    """Defines the options for truncating thread messages within a prompt."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_PROMPT_TOKENS_FIELD_NUMBER: builtins.int
    @property
    def max_prompt_tokens(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum number of tokens allowed in the prompt.
        If the prompt exceeds this limit, the thread messages will be truncated.
        Default max_prompt_tokens: 7000
        """

    def __init__(
        self,
        *,
        max_prompt_tokens: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_prompt_tokens", b"max_prompt_tokens"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_prompt_tokens", b"max_prompt_tokens"]) -> None: ...

global___PromptTruncationOptions = PromptTruncationOptions

@typing.final
class CompletionOptions(google.protobuf.message.Message):
    """Defines the options for completion generation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_TOKENS_FIELD_NUMBER: builtins.int
    TEMPERATURE_FIELD_NUMBER: builtins.int
    @property
    def max_tokens(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The limit on the number of tokens used for single completion generation.
        Must be greater than zero. This maximum allowed parameter value may depend on the model being used.
        """

    @property
    def temperature(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """Affects creativity and randomness of responses. Should be a double number between 0 (inclusive) and 1 (inclusive).
        Lower values produce more straightforward responses while higher values lead to increased creativity and randomness.
        Default temperature: 0.3
        """

    def __init__(
        self,
        *,
        max_tokens: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        temperature: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_tokens", b"max_tokens", "temperature", b"temperature"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_tokens", b"max_tokens", "temperature", b"temperature"]) -> None: ...

global___CompletionOptions = CompletionOptions

@typing.final
class SearchIndexTool(google.protobuf.message.Message):
    """Configures a tool that enables Retrieval-Augmented Generation (RAG) by allowing the assistant to search across a specified search index."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_INDEX_IDS_FIELD_NUMBER: builtins.int
    MAX_NUM_RESULTS_FIELD_NUMBER: builtins.int
    @property
    def search_index_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of search index IDs that this tool will query. Currently, only a single index ID is supported."""

    @property
    def max_num_results(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum number of results to return from the search.
        Fewer results may be returned if necessary to fit within the prompt's token limit.
        This ensures that the combined prompt and search results do not exceed the token constraints.
        """

    def __init__(
        self,
        *,
        search_index_ids: collections.abc.Iterable[builtins.str] | None = ...,
        max_num_results: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_num_results", b"max_num_results"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_num_results", b"max_num_results", "search_index_ids", b"search_index_ids"]) -> None: ...

global___SearchIndexTool = SearchIndexTool

@typing.final
class Tool(google.protobuf.message.Message):
    """Represents a general tool that can be one of several types."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_INDEX_FIELD_NUMBER: builtins.int
    @property
    def search_index(self) -> global___SearchIndexTool:
        """SearchIndexTool tool that performs search across specified indexes."""

    def __init__(
        self,
        *,
        search_index: global___SearchIndexTool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ToolType", b"ToolType", "search_index", b"search_index"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ToolType", b"ToolType", "search_index", b"search_index"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ToolType", b"ToolType"]) -> typing.Literal["search_index"] | None: ...

global___Tool = Tool



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cloudapps/workload/v1/cloud_application.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/cloudapps/workload/v1/cloud_application.proto\x12\"yandex.cloud.cloudapps.workload.v1\x1a\x1dyandex/cloud/validation.proto\"\x84\x05\n\x10\x43loudApplication\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12Q\n\x06status\x18\x02 \x01(\x0e\x32;.yandex.cloud.cloudapps.workload.v1.CloudApplication.StatusB\x04\xe8\xc7\x31\x01\x12S\n\x07\x62illing\x18\x03 \x01(\x0b\x32<.yandex.cloud.cloudapps.workload.v1.CloudApplication.BillingB\x04\xe8\xc7\x31\x01\x1a\xe1\x02\n\x07\x42illing\x12\\\n\x04type\x18\x01 \x01(\x0e\x32H.yandex.cloud.cloudapps.workload.v1.CloudApplication.Billing.BillingTypeB\x04\xe8\xc7\x31\x01\x12`\n\rsubscriptions\x18\x02 \x03(\x0b\x32I.yandex.cloud.cloudapps.workload.v1.CloudApplication.Billing.Subscription\x1a\x44\n\x0cSubscription\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0btemplate_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"P\n\x0b\x42illingType\x12\x1c\n\x18\x42ILLING_TYPE_UNSPECIFIED\x10\x00\x12\x11\n\rPAY_AS_YOU_GO\x10\x01\x12\x10\n\x0cSUBSCRIPTION\x10\x02\"J\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0e\n\nPROCESSING\x10\x01\x12\x0c\n\x08\x44\x45PLOYED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x42y\n&yandex.cloud.api.cloudapps.workload.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudapps/workload/v1;workloadb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cloudapps.workload.v1.cloud_application_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&yandex.cloud.api.cloudapps.workload.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudapps/workload/v1;workload'
  _CLOUDAPPLICATION_BILLING_SUBSCRIPTION.fields_by_name['instance_id']._options = None
  _CLOUDAPPLICATION_BILLING_SUBSCRIPTION.fields_by_name['instance_id']._serialized_options = b'\350\3071\001'
  _CLOUDAPPLICATION_BILLING_SUBSCRIPTION.fields_by_name['template_id']._options = None
  _CLOUDAPPLICATION_BILLING_SUBSCRIPTION.fields_by_name['template_id']._serialized_options = b'\350\3071\001'
  _CLOUDAPPLICATION_BILLING.fields_by_name['type']._options = None
  _CLOUDAPPLICATION_BILLING.fields_by_name['type']._serialized_options = b'\350\3071\001'
  _CLOUDAPPLICATION.fields_by_name['id']._options = None
  _CLOUDAPPLICATION.fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CLOUDAPPLICATION.fields_by_name['status']._options = None
  _CLOUDAPPLICATION.fields_by_name['status']._serialized_options = b'\350\3071\001'
  _CLOUDAPPLICATION.fields_by_name['billing']._options = None
  _CLOUDAPPLICATION.fields_by_name['billing']._serialized_options = b'\350\3071\001'
  _globals['_CLOUDAPPLICATION']._serialized_start=130
  _globals['_CLOUDAPPLICATION']._serialized_end=774
  _globals['_CLOUDAPPLICATION_BILLING']._serialized_start=345
  _globals['_CLOUDAPPLICATION_BILLING']._serialized_end=698
  _globals['_CLOUDAPPLICATION_BILLING_SUBSCRIPTION']._serialized_start=548
  _globals['_CLOUDAPPLICATION_BILLING_SUBSCRIPTION']._serialized_end=616
  _globals['_CLOUDAPPLICATION_BILLING_BILLINGTYPE']._serialized_start=618
  _globals['_CLOUDAPPLICATION_BILLING_BILLINGTYPE']._serialized_end=698
  _globals['_CLOUDAPPLICATION_STATUS']._serialized_start=700
  _globals['_CLOUDAPPLICATION_STATUS']._serialized_end=774
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.logging.v1.log_entry_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Registry(google.protobuf.message.Message):
    """A registry. For more information, see [Registry](/docs/iot-core/concepts/index#registry)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Registry._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Registry._Status.ValueType  # 0
        CREATING: Registry._Status.ValueType  # 1
        """Registry is being created."""
        ACTIVE: Registry._Status.ValueType  # 2
        """Registry is ready to use."""
        DELETING: Registry._Status.ValueType  # 3
        """Registry is being deleted."""
        DISABLED: Registry._Status.ValueType  # 4
        """Registry is disabled."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Registry.Status.ValueType  # 0
    CREATING: Registry.Status.ValueType  # 1
    """Registry is being created."""
    ACTIVE: Registry.Status.ValueType  # 2
    """Registry is ready to use."""
    DELETING: Registry.Status.ValueType  # 3
    """Registry is being deleted."""
    DISABLED: Registry.Status.ValueType  # 4
    """Registry is disabled."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the registry."""
    folder_id: builtins.str
    """ID of the folder that the registry belongs to."""
    name: builtins.str
    """Name of the registry. The name is unique within the folder."""
    description: builtins.str
    """Description of the registry. 0-256 characters long."""
    status: global___Registry.Status.ValueType
    """Status of the registry."""
    log_group_id: builtins.str
    """ID of the logs group for the specified registry."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs. Maximum of 64 per resource."""

    @property
    def log_options(self) -> global___LogOptions:
        """Options for logging registry events"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status: global___Registry.Status.ValueType = ...,
        log_group_id: builtins.str = ...,
        log_options: global___LogOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "log_options", b"log_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "log_group_id", b"log_group_id", "log_options", b"log_options", "name", b"name", "status", b"status"]) -> None: ...

global___Registry = Registry

@typing.final
class RegistryCertificate(google.protobuf.message.Message):
    """A registry certificate. For more information, see [Managing registry certificates](/docs/iot-core/operations/certificates/registry-certificates)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    CERTIFICATE_DATA_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry that the certificate belongs to."""
    fingerprint: builtins.str
    """SHA256 hash of the certificates."""
    certificate_data: builtins.str
    """Public part of the certificate."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        fingerprint: builtins.str = ...,
        certificate_data: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["certificate_data", b"certificate_data", "created_at", b"created_at", "fingerprint", b"fingerprint", "registry_id", b"registry_id"]) -> None: ...

global___RegistryCertificate = RegistryCertificate

@typing.final
class DeviceAlias(google.protobuf.message.Message):
    """A device topic alias.

    Alias is an alternate name of a device topic assigned by the user. Map alias to canonical topic name prefix, e.g. `my/custom/alias` match to `$device/abcdef/events`. For more information, see [Using topic aliases](/docs/iot-core/concepts/topic#aliases).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    TOPIC_PREFIX_FIELD_NUMBER: builtins.int
    ALIAS_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device that the alias belongs to."""
    topic_prefix: builtins.str
    """Prefix of a canonical topic name to be aliased, e.g. `$devices/abcdef`."""
    alias: builtins.str
    """Alias of a device topic."""
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        topic_prefix: builtins.str = ...,
        alias: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["alias", b"alias", "device_id", b"device_id", "topic_prefix", b"topic_prefix"]) -> None: ...

global___DeviceAlias = DeviceAlias

@typing.final
class RegistryPassword(google.protobuf.message.Message):
    """A registry password."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry that the password belongs to."""
    id: builtins.str
    """ID of the password."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "id", b"id", "registry_id", b"registry_id"]) -> None: ...

global___RegistryPassword = RegistryPassword

@typing.final
class DataStreamExport(google.protobuf.message.Message):
    """A Yandex Data Streams export."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REGISTRY_ID_FIELD_NUMBER: builtins.int
    MQTT_TOPIC_FILTER_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    STREAM_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the YDS export."""
    name: builtins.str
    """Name of the YDS export."""
    registry_id: builtins.str
    """ID of the registry that the YDS export belongs to."""
    mqtt_topic_filter: builtins.str
    """MQTT topic whose messages export to YDS."""
    database: builtins.str
    """YDS database."""
    stream: builtins.str
    """YDS stream name."""
    service_account_id: builtins.str
    """ID of the service account which has permission to write to data stream."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        registry_id: builtins.str = ...,
        mqtt_topic_filter: builtins.str = ...,
        database: builtins.str = ...,
        stream: builtins.str = ...,
        service_account_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "database", b"database", "id", b"id", "mqtt_topic_filter", b"mqtt_topic_filter", "name", b"name", "registry_id", b"registry_id", "service_account_id", b"service_account_id", "stream", b"stream"]) -> None: ...

global___DataStreamExport = DataStreamExport

@typing.final
class LogOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    MIN_LEVEL_FIELD_NUMBER: builtins.int
    disabled: builtins.bool
    """Is logging from registry disabled."""
    log_group_id: builtins.str
    """Entry should be written to log group resolved by ID."""
    folder_id: builtins.str
    """Entry should be written to default log group for specified folder."""
    min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType
    """Minimum log entry level.

    See [LogLevel.Level] for details.
    """
    def __init__(
        self,
        *,
        disabled: builtins.bool = ...,
        log_group_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destination", b"destination", "disabled", b"disabled", "folder_id", b"folder_id", "log_group_id", b"log_group_id", "min_level", b"min_level"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["log_group_id", "folder_id"] | None: ...

global___LogOptions = LogOptions



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/zone_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.compute.v1 import zone_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_zone__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/compute/v1/zone_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a\"yandex/cloud/compute/v1/zone.proto\x1a\x1dyandex/cloud/validation.proto\"P\n\x10ListZonesRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\"Z\n\x11ListZonesResponse\x12,\n\x05zones\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.compute.v1.Zone\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"/\n\x0eGetZoneRequest\x12\x1d\n\x07zone_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502\xfb\x01\n\x0bZoneService\x12r\n\x03Get\x12\'.yandex.cloud.compute.v1.GetZoneRequest\x1a\x1d.yandex.cloud.compute.v1.Zone\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/compute/v1/zones/{zone_id}\x12x\n\x04List\x12).yandex.cloud.compute.v1.ListZonesRequest\x1a*.yandex.cloud.compute.v1.ListZonesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/compute/v1/zonesBb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.zone_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _LISTZONESREQUEST.fields_by_name['page_size']._options = None
  _LISTZONESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTZONESREQUEST.fields_by_name['page_token']._options = None
  _LISTZONESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _GETZONEREQUEST.fields_by_name['zone_id']._options = None
  _GETZONEREQUEST.fields_by_name['zone_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ZONESERVICE.methods_by_name['Get']._options = None
  _ZONESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\035\022\033/compute/v1/zones/{zone_id}'
  _ZONESERVICE.methods_by_name['List']._options = None
  _ZONESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\023\022\021/compute/v1/zones'
  _globals['_LISTZONESREQUEST']._serialized_start=168
  _globals['_LISTZONESREQUEST']._serialized_end=248
  _globals['_LISTZONESRESPONSE']._serialized_start=250
  _globals['_LISTZONESRESPONSE']._serialized_end=340
  _globals['_GETZONEREQUEST']._serialized_start=342
  _globals['_GETZONEREQUEST']._serialized_end=389
  _globals['_ZONESERVICE']._serialized_start=392
  _globals['_ZONESERVICE']._serialized_end=643
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/rate_limit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/apploadbalancer/v1/rate_limit.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1dyandex/cloud/validation.proto\"\xf1\x01\n\tRateLimit\x12\x46\n\x0c\x61ll_requests\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.apploadbalancer.v1.RateLimit.Limit\x12I\n\x0frequests_per_ip\x18\x04 \x01(\x0b\x32\x30.yandex.cloud.apploadbalancer.v1.RateLimit.Limit\x1aQ\n\x05Limit\x12\x1c\n\nper_second\x18\x01 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0H\x00\x12\x1c\n\nper_minute\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0H\x00\x42\x0c\n\x04rate\x12\x04\xc0\xc1\x31\x01\x42z\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.apploadbalancer.v1.rate_limit_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer'
  _RATELIMIT_LIMIT.oneofs_by_name['rate']._options = None
  _RATELIMIT_LIMIT.oneofs_by_name['rate']._serialized_options = b'\300\3011\001'
  _RATELIMIT_LIMIT.fields_by_name['per_second']._options = None
  _RATELIMIT_LIMIT.fields_by_name['per_second']._serialized_options = b'\372\3071\002>0'
  _RATELIMIT_LIMIT.fields_by_name['per_minute']._options = None
  _RATELIMIT_LIMIT.fields_by_name['per_minute']._serialized_options = b'\372\3071\002>0'
  _globals['_RATELIMIT']._serialized_start=117
  _globals['_RATELIMIT']._serialized_end=358
  _globals['_RATELIMIT_LIMIT']._serialized_start=277
  _globals['_RATELIMIT_LIMIT']._serialized_end=358
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.loadtesting.api.v1.test.object_storage_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class FilePointer(google.protobuf.message.Message):
    """Variant-like structure for referencing files in different sources."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_STORAGE_FIELD_NUMBER: builtins.int
    @property
    def object_storage(self) -> yandex.cloud.loadtesting.api.v1.test.object_storage_pb2.ObjectStorage:
        """Reference to a file in Object Storage."""

    def __init__(
        self,
        *,
        object_storage: yandex.cloud.loadtesting.api.v1.test.object_storage_pb2.ObjectStorage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["file_pointer", b"file_pointer", "object_storage", b"object_storage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["file_pointer", b"file_pointer", "object_storage", b"object_storage"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["file_pointer", b"file_pointer"]) -> typing.Literal["object_storage"] | None: ...

global___FilePointer = FilePointer



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/awscompatibility/access_key_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.iam.v1.awscompatibility import access_key_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_awscompatibility_dot_access__key__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=yandex/cloud/iam/v1/awscompatibility/access_key_service.proto\x12$yandex.cloud.iam.v1.awscompatibility\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x35yandex/cloud/iam/v1/awscompatibility/access_key.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\":\n\x13GetAccessKeyRequest\x12#\n\raccess_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"|\n\x15ListAccessKeysRequest\x12$\n\x12service_account_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"w\n\x16ListAccessKeysResponse\x12\x44\n\x0b\x61\x63\x63\x65ss_keys\x18\x01 \x03(\x0b\x32/.yandex.cloud.iam.v1.awscompatibility.AccessKey\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"^\n\x16\x43reateAccessKeyRequest\x12$\n\x12service_account_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\"n\n\x17\x43reateAccessKeyResponse\x12\x43\n\naccess_key\x18\x01 \x01(\x0b\x32/.yandex.cloud.iam.v1.awscompatibility.AccessKey\x12\x0e\n\x06secret\x18\x02 \x01(\t\"\x8e\x01\n\x16UpdateAccessKeyRequest\x12#\n\raccess_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\"0\n\x17UpdateAccessKeyMetadata\x12\x15\n\raccess_key_id\x18\x01 \x01(\t\"=\n\x16\x44\x65leteAccessKeyRequest\x12#\n\raccess_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"0\n\x17\x44\x65leteAccessKeyMetadata\x12\x15\n\raccess_key_id\x18\x01 \x01(\t\"\x84\x01\n\x1eListAccessKeyOperationsRequest\x12#\n\raccess_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"q\n\x1fListAccessKeyOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xcb\t\n\x10\x41\x63\x63\x65ssKeyService\x12\xaf\x01\n\x04List\x12;.yandex.cloud.iam.v1.awscompatibility.ListAccessKeysRequest\x1a<.yandex.cloud.iam.v1.awscompatibility.ListAccessKeysResponse\",\x82\xd3\xe4\x93\x02&\x12$/iam/aws-compatibility/v1/accessKeys\x12\xaf\x01\n\x03Get\x12\x39.yandex.cloud.iam.v1.awscompatibility.GetAccessKeyRequest\x1a/.yandex.cloud.iam.v1.awscompatibility.AccessKey\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/iam/aws-compatibility/v1/accessKeys/{access_key_id}\x12\xb6\x01\n\x06\x43reate\x12<.yandex.cloud.iam.v1.awscompatibility.CreateAccessKeyRequest\x1a=.yandex.cloud.iam.v1.awscompatibility.CreateAccessKeyResponse\"/\x82\xd3\xe4\x93\x02)\"$/iam/aws-compatibility/v1/accessKeys:\x01*\x12\xd2\x01\n\x06Update\x12<.yandex.cloud.iam.v1.awscompatibility.UpdateAccessKeyRequest\x1a!.yandex.cloud.operation.Operation\"g\xb2\xd2*$\n\x17UpdateAccessKeyMetadata\x12\tAccessKey\x82\xd3\xe4\x93\x02\x39\x32\x34/iam/aws-compatibility/v1/accessKeys/{access_key_id}:\x01*\x12\xdb\x01\n\x06\x44\x65lete\x12<.yandex.cloud.iam.v1.awscompatibility.DeleteAccessKeyRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*0\n\x17\x44\x65leteAccessKeyMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x36*4/iam/aws-compatibility/v1/accessKeys/{access_key_id}\x12\xe6\x01\n\x0eListOperations\x12\x44.yandex.cloud.iam.v1.awscompatibility.ListAccessKeyOperationsRequest\x1a\x45.yandex.cloud.iam.v1.awscompatibility.ListAccessKeyOperationsResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/iam/aws-compatibility/v1/accessKeys/{access_key_id}/operationsB\x85\x01\n(yandex.cloud.api.iam.v1.awscompatibilityZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1/awscompatibility;awscompatibilityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.iam.v1.awscompatibilityZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1/awscompatibility;awscompatibility'
  _GETACCESSKEYREQUEST.fields_by_name['access_key_id']._options = None
  _GETACCESSKEYREQUEST.fields_by_name['access_key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTACCESSKEYSREQUEST.fields_by_name['service_account_id']._options = None
  _LISTACCESSKEYSREQUEST.fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _LISTACCESSKEYSREQUEST.fields_by_name['page_size']._options = None
  _LISTACCESSKEYSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTACCESSKEYSREQUEST.fields_by_name['page_token']._options = None
  _LISTACCESSKEYSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _CREATEACCESSKEYREQUEST.fields_by_name['service_account_id']._options = None
  _CREATEACCESSKEYREQUEST.fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _CREATEACCESSKEYREQUEST.fields_by_name['description']._options = None
  _CREATEACCESSKEYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEACCESSKEYREQUEST.fields_by_name['access_key_id']._options = None
  _UPDATEACCESSKEYREQUEST.fields_by_name['access_key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEACCESSKEYREQUEST.fields_by_name['description']._options = None
  _UPDATEACCESSKEYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _DELETEACCESSKEYREQUEST.fields_by_name['access_key_id']._options = None
  _DELETEACCESSKEYREQUEST.fields_by_name['access_key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTACCESSKEYOPERATIONSREQUEST.fields_by_name['access_key_id']._options = None
  _LISTACCESSKEYOPERATIONSREQUEST.fields_by_name['access_key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTACCESSKEYOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTACCESSKEYOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTACCESSKEYOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTACCESSKEYOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _ACCESSKEYSERVICE.methods_by_name['List']._options = None
  _ACCESSKEYSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002&\022$/iam/aws-compatibility/v1/accessKeys'
  _ACCESSKEYSERVICE.methods_by_name['Get']._options = None
  _ACCESSKEYSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0026\0224/iam/aws-compatibility/v1/accessKeys/{access_key_id}'
  _ACCESSKEYSERVICE.methods_by_name['Create']._options = None
  _ACCESSKEYSERVICE.methods_by_name['Create']._serialized_options = b'\202\323\344\223\002)\"$/iam/aws-compatibility/v1/accessKeys:\001*'
  _ACCESSKEYSERVICE.methods_by_name['Update']._options = None
  _ACCESSKEYSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*$\n\027UpdateAccessKeyMetadata\022\tAccessKey\202\323\344\223\002924/iam/aws-compatibility/v1/accessKeys/{access_key_id}:\001*'
  _ACCESSKEYSERVICE.methods_by_name['Delete']._options = None
  _ACCESSKEYSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*0\n\027DeleteAccessKeyMetadata\022\025google.protobuf.Empty\202\323\344\223\0026*4/iam/aws-compatibility/v1/accessKeys/{access_key_id}'
  _ACCESSKEYSERVICE.methods_by_name['ListOperations']._options = None
  _ACCESSKEYSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002A\022?/iam/aws-compatibility/v1/accessKeys/{access_key_id}/operations'
  _globals['_GETACCESSKEYREQUEST']._serialized_start=327
  _globals['_GETACCESSKEYREQUEST']._serialized_end=385
  _globals['_LISTACCESSKEYSREQUEST']._serialized_start=387
  _globals['_LISTACCESSKEYSREQUEST']._serialized_end=511
  _globals['_LISTACCESSKEYSRESPONSE']._serialized_start=513
  _globals['_LISTACCESSKEYSRESPONSE']._serialized_end=632
  _globals['_CREATEACCESSKEYREQUEST']._serialized_start=634
  _globals['_CREATEACCESSKEYREQUEST']._serialized_end=728
  _globals['_CREATEACCESSKEYRESPONSE']._serialized_start=730
  _globals['_CREATEACCESSKEYRESPONSE']._serialized_end=840
  _globals['_UPDATEACCESSKEYREQUEST']._serialized_start=843
  _globals['_UPDATEACCESSKEYREQUEST']._serialized_end=985
  _globals['_UPDATEACCESSKEYMETADATA']._serialized_start=987
  _globals['_UPDATEACCESSKEYMETADATA']._serialized_end=1035
  _globals['_DELETEACCESSKEYREQUEST']._serialized_start=1037
  _globals['_DELETEACCESSKEYREQUEST']._serialized_end=1098
  _globals['_DELETEACCESSKEYMETADATA']._serialized_start=1100
  _globals['_DELETEACCESSKEYMETADATA']._serialized_end=1148
  _globals['_LISTACCESSKEYOPERATIONSREQUEST']._serialized_start=1151
  _globals['_LISTACCESSKEYOPERATIONSREQUEST']._serialized_end=1283
  _globals['_LISTACCESSKEYOPERATIONSRESPONSE']._serialized_start=1285
  _globals['_LISTACCESSKEYOPERATIONSRESPONSE']._serialized_end=1398
  _globals['_ACCESSKEYSERVICE']._serialized_start=1401
  _globals['_ACCESSKEYSERVICE']._serialized_end=2628
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/airflow/v1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.airflow.v1 import common_pb2 as yandex_dot_cloud_dot_airflow_dot_v1_dot_common__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%yandex/cloud/airflow/v1/cluster.proto\x12\x17yandex.cloud.airflow.v1\x1a$yandex/cloud/airflow/v1/common.proto\x1a\x1dyandex/cloud/validation.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcc\x06\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12<\n\x06labels\x18\x06 \x03(\x0b\x32,.yandex.cloud.airflow.v1.Cluster.LabelsEntry\x12\x37\n\nmonitoring\x18\x08 \x03(\x0b\x32#.yandex.cloud.airflow.v1.Monitoring\x12\x36\n\x06\x63onfig\x18\t \x01(\x0b\x32&.yandex.cloud.airflow.v1.ClusterConfig\x12/\n\x06health\x18\n \x01(\x0e\x32\x1f.yandex.cloud.airflow.v1.Health\x12\x37\n\x06status\x18\x0b \x01(\x0e\x32\'.yandex.cloud.airflow.v1.Cluster.Status\x12\x37\n\x07network\x18\x0c \x01(\x0b\x32&.yandex.cloud.airflow.v1.NetworkConfig\x12:\n\tcode_sync\x18\r \x01(\x0b\x32\'.yandex.cloud.airflow.v1.CodeSyncConfig\x12\x1b\n\x13\x64\x65letion_protection\x18\x0e \x01(\x08\x12\x15\n\rwebserver_url\x18\x0f \x01(\t\x12$\n\x12service_account_id\x18\x10 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x37\n\x07logging\x18\x11 \x01(\x0b\x32&.yandex.cloud.airflow.v1.LoggingConfig\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\x0c\n\x08STARTING\x10\x06\x12\x0c\n\x08UPDATING\x10\x07J\x04\x08\x07\x10\x08\"=\n\nMonitoring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"\xd2\x03\n\rClusterConfig\x12\x12\n\nversion_id\x18\x01 \x01(\t\x12\x37\n\x07\x61irflow\x18\x02 \x01(\x0b\x32&.yandex.cloud.airflow.v1.AirflowConfig\x12\x41\n\twebserver\x18\x03 \x01(\x0b\x32(.yandex.cloud.airflow.v1.WebserverConfigB\x04\xe8\xc7\x31\x01\x12\x41\n\tscheduler\x18\x04 \x01(\x0b\x32(.yandex.cloud.airflow.v1.SchedulerConfigB\x04\xe8\xc7\x31\x01\x12;\n\ttriggerer\x18\x05 \x01(\x0b\x32(.yandex.cloud.airflow.v1.TriggererConfig\x12;\n\x06worker\x18\x06 \x01(\x0b\x32%.yandex.cloud.airflow.v1.WorkerConfigB\x04\xe8\xc7\x31\x01\x12;\n\x0c\x64\x65pendencies\x18\x07 \x01(\x0b\x32%.yandex.cloud.airflow.v1.Dependencies\x12\x37\n\x07lockbox\x18\x08 \x01(\x0b\x32&.yandex.cloud.airflow.v1.LockboxConfig\"\x82\x01\n\rAirflowConfig\x12\x42\n\x06\x63onfig\x18\x01 \x03(\x0b\x32\x32.yandex.cloud.airflow.v1.AirflowConfig.ConfigEntry\x1a-\n\x0b\x43onfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n\x0fWebserverConfig\x12\x18\n\x05\x63ount\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-512\x12\x35\n\tresources\x18\x02 \x01(\x0b\x32\".yandex.cloud.airflow.v1.Resources\"b\n\x0fSchedulerConfig\x12\x18\n\x05\x63ount\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-512\x12\x35\n\tresources\x18\x02 \x01(\x0b\x32\".yandex.cloud.airflow.v1.Resources\"b\n\x0fTriggererConfig\x12\x18\n\x05\x63ount\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-512\x12\x35\n\tresources\x18\x02 \x01(\x0b\x32\".yandex.cloud.airflow.v1.Resources\"\x81\x01\n\x0cWorkerConfig\x12\x1c\n\tmin_count\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-512\x12\x1c\n\tmax_count\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-512\x12\x35\n\tresources\x18\x03 \x01(\x0b\x32\".yandex.cloud.airflow.v1.Resources\":\n\x0c\x44\x65pendencies\x12\x14\n\x0cpip_packages\x18\x01 \x03(\t\x12\x14\n\x0c\x64\x65\x62_packages\x18\x02 \x03(\t\"?\n\rNetworkConfig\x12\x12\n\nsubnet_ids\x18\x01 \x03(\t\x12\x1a\n\x12security_group_ids\x18\x02 \x03(\t\"\x1a\n\x08S3Config\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\"Q\n\x0e\x43odeSyncConfig\x12/\n\x02s3\x18\x01 \x01(\x0b\x32!.yandex.cloud.airflow.v1.S3ConfigH\x00\x42\x0e\n\x06source\x12\x04\xc0\xc1\x31\x01\"\xe2\x01\n\rLoggingConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x38\n\tfolder_id\x18\x02 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12;\n\x0clog_group_id\x18\x03 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12:\n\tmin_level\x18\x04 \x01(\x0e\x32\'.yandex.cloud.logging.v1.LogLevel.LevelB\r\n\x0b\x64\x65stination\" \n\rLockboxConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x42\x62\n\x1byandex.cloud.api.airflow.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/airflow/v1;airflowb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.airflow.v1.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.airflow.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/airflow/v1;airflow'
  _CLUSTER_LABELSENTRY._options = None
  _CLUSTER_LABELSENTRY._serialized_options = b'8\001'
  _CLUSTER.fields_by_name['service_account_id']._options = None
  _CLUSTER.fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _CLUSTERCONFIG.fields_by_name['webserver']._options = None
  _CLUSTERCONFIG.fields_by_name['webserver']._serialized_options = b'\350\3071\001'
  _CLUSTERCONFIG.fields_by_name['scheduler']._options = None
  _CLUSTERCONFIG.fields_by_name['scheduler']._serialized_options = b'\350\3071\001'
  _CLUSTERCONFIG.fields_by_name['worker']._options = None
  _CLUSTERCONFIG.fields_by_name['worker']._serialized_options = b'\350\3071\001'
  _AIRFLOWCONFIG_CONFIGENTRY._options = None
  _AIRFLOWCONFIG_CONFIGENTRY._serialized_options = b'8\001'
  _WEBSERVERCONFIG.fields_by_name['count']._options = None
  _WEBSERVERCONFIG.fields_by_name['count']._serialized_options = b'\372\3071\0051-512'
  _SCHEDULERCONFIG.fields_by_name['count']._options = None
  _SCHEDULERCONFIG.fields_by_name['count']._serialized_options = b'\372\3071\0051-512'
  _TRIGGERERCONFIG.fields_by_name['count']._options = None
  _TRIGGERERCONFIG.fields_by_name['count']._serialized_options = b'\372\3071\0050-512'
  _WORKERCONFIG.fields_by_name['min_count']._options = None
  _WORKERCONFIG.fields_by_name['min_count']._serialized_options = b'\372\3071\0050-512'
  _WORKERCONFIG.fields_by_name['max_count']._options = None
  _WORKERCONFIG.fields_by_name['max_count']._serialized_options = b'\372\3071\0051-512'
  _CODESYNCCONFIG.oneofs_by_name['source']._options = None
  _CODESYNCCONFIG.oneofs_by_name['source']._serialized_options = b'\300\3011\001'
  _LOGGINGCONFIG.fields_by_name['folder_id']._options = None
  _LOGGINGCONFIG.fields_by_name['folder_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _LOGGINGCONFIG.fields_by_name['log_group_id']._options = None
  _LOGGINGCONFIG.fields_by_name['log_group_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _globals['_CLUSTER']._serialized_start=210
  _globals['_CLUSTER']._serialized_end=1054
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=880
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=925
  _globals['_CLUSTER_STATUS']._serialized_start=927
  _globals['_CLUSTER_STATUS']._serialized_end=1048
  _globals['_MONITORING']._serialized_start=1056
  _globals['_MONITORING']._serialized_end=1117
  _globals['_CLUSTERCONFIG']._serialized_start=1120
  _globals['_CLUSTERCONFIG']._serialized_end=1586
  _globals['_AIRFLOWCONFIG']._serialized_start=1589
  _globals['_AIRFLOWCONFIG']._serialized_end=1719
  _globals['_AIRFLOWCONFIG_CONFIGENTRY']._serialized_start=1674
  _globals['_AIRFLOWCONFIG_CONFIGENTRY']._serialized_end=1719
  _globals['_WEBSERVERCONFIG']._serialized_start=1721
  _globals['_WEBSERVERCONFIG']._serialized_end=1819
  _globals['_SCHEDULERCONFIG']._serialized_start=1821
  _globals['_SCHEDULERCONFIG']._serialized_end=1919
  _globals['_TRIGGERERCONFIG']._serialized_start=1921
  _globals['_TRIGGERERCONFIG']._serialized_end=2019
  _globals['_WORKERCONFIG']._serialized_start=2022
  _globals['_WORKERCONFIG']._serialized_end=2151
  _globals['_DEPENDENCIES']._serialized_start=2153
  _globals['_DEPENDENCIES']._serialized_end=2211
  _globals['_NETWORKCONFIG']._serialized_start=2213
  _globals['_NETWORKCONFIG']._serialized_end=2276
  _globals['_S3CONFIG']._serialized_start=2278
  _globals['_S3CONFIG']._serialized_end=2304
  _globals['_CODESYNCCONFIG']._serialized_start=2306
  _globals['_CODESYNCCONFIG']._serialized_end=2387
  _globals['_LOGGINGCONFIG']._serialized_start=2390
  _globals['_LOGGINGCONFIG']._serialized_end=2616
  _globals['_LOCKBOXCONFIG']._serialized_start=2618
  _globals['_LOCKBOXCONFIG']._serialized_end=2650
# @@protoc_insertion_point(module_scope)
